netapp_ontap.resources.azure_key_vault API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.azure_key_vault`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Azure Key Vault (AKV) is a cloud key management service (KMS) that provides a secure store for secrets. This feature allows ONTAP to securely store its encryption keys using AKV. In order to use AKV with ONTAP, you must first deploy an Azure application with the appropriate access to an AKV and then provide ONTAP with the necessary details, such as key vault name, application ID so that ONTAP can communicate with the deployed Azure application. The properties "state", "azure_reachability" and "ekmip_reachability" are considered advanced properties and are populated only when explicitly requested.

## Examples

### Creating an AKV for a cluster

The example AKV is configured at the cluster-scope. Note the return_records=true query parameter is used to obtain the newly created key manager configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault()
        resource.client_id = "client1"
        resource.tenant_id = "tenant1"
        resource.name = "https:://mykeyvault.azure.vault.net/"
        resource.key_id = "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74"
        resource.client_secret = "myclientPwd"
        resource.post(hydrate=True)
        print(resource)

Try it out

    AzureKeyVault(
        {
            "client_id": "client1",
            "key_id": "https://keyvault-test.vault.azure.net/keys/key1",
            "tenant_id": "tenant1",
            "_links": {
                "self": {
                    "href": "/api/security/azure-key-vaults/85619643-9a06-11ea-8d52-005056bbeba5"
                }
            },
            "name": "https:://mykeyvault.azure.vault.net/",
            "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
        }
    )

### Creating an AKV for an SVM

The example AKV is configured for a specific SVM. Note the return_records=true query parameter is used to obtain the newly created key manager configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault()
        resource.svm.uuid = "4f7abf4c-9a07-11ea-8d52-005056bbeba5"
        resource.client_id = "client1"
        resource.tenant_id = "tenant1"
        resource.name = "https:://mykeyvault.azure.vault.net/"
        resource.key_id = "https://keyvault-test.vault.azure.net/keys/key1"
        resource.client_secret = "myclientPwd"
        resource.post(hydrate=True)
        print(resource)

Try it out

    AzureKeyVault(
        {
            "client_id": "client1",
            "svm": {"uuid": "4f7abf4c-9a07-11ea-8d52-005056bbeba5", "name": "vs0"},
            "key_id": "https://keyvault-test.vault.azure.net/keys/key1",
            "tenant_id": "tenant1",
            "_links": {
                "self": {
                    "href": "/api/security/azure-key-vaults/024cd3cf-9a08-11ea-8d52-005056bbeba5"
                }
            },
            "name": "https:://mykeyvault.azure.vault.net/",
            "uuid": "024cd3cf-9a08-11ea-8d52-005056bbeba5",
        }
    )

### Retrieving the AKVs configured for all clusters and SVMs

The following example shows how to retrieve all configured AKVs along with their configurations.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(AzureKeyVault.get_collection(fields="*")))

Try it out

    [
        AzureKeyVault(
            {
                "client_id": "client1",
                "svm": {"uuid": "4f7abf4c-9a07-11ea-8d52-005056bbeba5", "name": "vs0"},
                "key_id": "https://keyvault-test.vault.azure.net/keys/key1",
                "tenant_id": "tenant1",
                "_links": {
                    "self": {
                        "href": "/api/security/azure-key-vaults/024cd3cf-9a08-11ea-8d52-005056bbeba5"
                    }
                },
                "state": {"message": "", "code": 0},
                "name": "https:://mykeyvault.azure.vault.net/",
                "scope": "svm",
                "uuid": "024cd3cf-9a08-11ea-8d52-005056bbeba5",
            }
        ),
        AzureKeyVault(
            {
                "client_id": "client1",
                "key_id": "https://keyvault-test.vault.azure.net/keys/key1",
                "tenant_id": "tenant1",
                "_links": {
                    "self": {
                        "href": "/api/security/azure-key-vaults/85619643-9a06-11ea-8d52-005056bbeba5"
                    }
                },
                "state": {"message": "", "code": 0},
                "name": "https:://mykeyvault.azure.vault.net/",
                "scope": "cluster",
                "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
            }
        ),
    ]

### Retrieving the AKV configured for a specific SVM

The following example retrieves a configured AKV for a specific SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.get(fields="*")
        print(resource)

Try it out

    AzureKeyVault(
        {
            "client_id": "client1",
            "key_id": "https://keyvault-test.vault.azure.net/keys/key1",
            "tenant_id": "tenant1",
            "_links": {
                "self": {
                    "href": "/api/security/azure-key-vaults/85619643-9a06-11ea-8d52-005056bbeba5"
                }
            },
            "state": {"message": "", "code": 0},
            "name": "https:://mykeyvault.azure.vault.net/",
            "scope": "cluster",
            "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
        }
    )

### Retrieving the advanced properties of an AKV configured for a specific SVM

The following example retrieves the advanced properties of a configured AKV for a specific SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.get(fields='state,azure_reachability,ekmip_reachability"')
        print(resource)

### Updating the client password of a specific SVM

The following example updates the client password of a configured AKV for a specific SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.client_secret = "newSecret"
        resource.patch()

### Deleting an AKV configuration for a specific SVM

The following example deletes a configured AKV for a specific SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.delete()

### Restoring the keys for a specific SVM configured with an AKV

The following example restores all the keys of a specific SVM configured with an AKV.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.restore()

Try it out

    AzureKeyVault({})

### Rekeying the internal key for a specific SVM configured with an AKV

The following example rekeys the internal key of a specific SVM configured with an AKV.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.rekey_internal()

Try it out

    AzureKeyVault({})

## Classes

`class AzureKeyVault (*args, **kwargs)`

  Allows interaction with AzureKeyVault objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves AKVs configured for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an AKV configuration.

    ### Related ONTAP commands

    - `security key-manager external azure disable`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves AKVs configured for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves AKVs configured for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the AKV configuration.

    ### Optional properties

    - `client_secret` - New password used to prove the application's identity to the AKV.
    - `key_id`- Key Identifier of the new AKV key encryption key.
    - `proxy_type`` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.

    ### Related ONTAP commands

    - `security key-manager external azure update-client-secret`
    - `security key-manager external azure rekey-external`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an AKV configuration.

    ### Related ONTAP commands

    - `security key-manager external azure disable`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the AKV configuration for the SVM specified by the UUID.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the AKV configuration.

    ### Optional properties

    - `client_secret` - New password used to prove the application's identity to the AKV.
    - `key_id`- Key Identifier of the new AKV key encryption key.
    - `proxy_type`` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.

    ### Related ONTAP commands

    - `security key-manager external azure update-client-secret`
    - `security key-manager external azure rekey-external`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Configures the AKV configuration for all clusters and SVMs.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create a AKV.
    - `client_id` - Application (client) ID of the deployed Azure application with appropriate access to an AKV.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.
    - `client_secret` - Password used by the application to prove its identity to AKV.
    - `key_id`- Key Identifier of AKV encryption key.
    - `name` - Name of the deployed AKV used by ONTAP for storing keys.

    ### Optional properties

    - `proxy_type`` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.

    ### Related ONTAP commands

    - `security key-manager external azure enable`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def rekey_internal(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Rekeys the internal key in the key hierarchy for an SVM with an AKV configuration.

    ### Related ONTAP commands

    - `security key-manager external azure rekey-internal`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def restore(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Restore the keys for an SVM from a configured AKV.

    ### Related ONTAP commands

    - `security key-manager external azure restore`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class AzureKeyVaultSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AzureKeyVault object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `azure_reachability GET`

    The azure_reachability field of the azure_key_vault.

  `client_id GET POST`

    Application client ID of the deployed Azure application with appropriate access to an AKV.

    Example: aaaaaaaa-bbbb-aaaa-bbbb-aaaaaaaaaaaa

  `client_secret POST PATCH`

    Password used by the application to prove its identity to AKV.

    Example: abcdef

  `ekmip_reachability GET`

    The ekmip_reachability field of the azure_key_vault.

  `key_id GET POST PATCH`

    Key Identifier of AKV key encryption key.

    Example: https://keyvault1.vault.azure.net/keys/key1

  `links GET`

    The links field of the azure_key_vault.

  `name GET POST`

    Name of the deployed AKV that will be used by ONTAP for storing keys.

    Example: https://kmip-akv-keyvault.vault.azure.net/

  `proxy_host GET POST PATCH`

    Proxy host.

    Example: proxy.eng.com

  `proxy_password POST PATCH`

    Proxy password. Password is not audited.

    Example: proxypassword

  `proxy_port GET POST PATCH`

    Proxy port.

    Example: 1234

  `proxy_type GET POST PATCH`

    Type of proxy.

    Valid choices:

    - http
    - https
  `proxy_username GET POST PATCH`

    Proxy username.

    Example: proxyuser

  `scope GET`

    Set to "svm" for interfaces owned by an SVM. Otherwise, set to "cluster".

    Valid choices:

    - svm
    - cluster
  `state GET`

    The state field of the azure_key_vault.

  `svm GET POST PATCH`

    The svm field of the azure_key_vault.

  `tenant_id GET POST`

    Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.

    Example: zzzzzzzz-yyyy-zzzz-yyyy-zzzzzzzzzzzz

  `uuid GET`

    A unique identifier for the Azure Key Vault (AKV).

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412